
/* Includes ------------------------------------------------------------------*/

#include "freertos/FreeRTOS.h"
#include "freertos/task.h"
#include "freertos/event_groups.h"
#include "freertos/queue.h"
#include "esp_system.h"
#include "esp_types.h"
#include "esp_err.h"
#include "esp_log.h"
#include "nvs_flash.h"
#include "nvs.h"

#define TASK_STACK_SIZE_APP 5120
#define TASK_PRIORITY_APP 4

#define MS_TO_RTOS_TICKS(x) (x / portTICK_PERIOD_MS)
#define TASK_DELAY_MS(x) vTaskDelay(MS_TO_RTOS_TICKS(x))

/* Variables -----------------------------------------------------------------*/
TaskHandle_t tHandle_appTask = NULL;

void flash_initNvs()
{
    printf("\n[%s]", __func__);
    esp_err_t err = nvs_flash_init();
    if ((ESP_ERR_NVS_NO_FREE_PAGES == err) || (ESP_ERR_NVS_NEW_VERSION_FOUND == err))
    {
        ESP_ERROR_CHECK(nvs_flash_erase());
        err = nvs_flash_init();
    }
    ESP_ERROR_CHECK(err);
}

void app_task(void *param)
{
    printf("\n[%s]", __func__);

    while (true)
    {
        TASK_DELAY_MS(10);
    }
}

void app_init()
{
    printf("\n[%s]", __func__);
    flash_initNvs();
}

/**
* @brief    entry point of the project
* @param    None
* @return   None
*/
void app_main()
{
    printf("\n[%s]", __func__);
    app_init();

    if (xTaskCreate(&app_task, "app_task", TASK_STACK_SIZE_APP, NULL, TASK_PRIORITY_APP, &tHandle_appTask) != pdTRUE)
    {
        printf("\n Error create app_task \n restarting system\r\n\r\n");
        esp_restart();
    }
}
